#!/usr/bin/env python3

import argparse
import pathlib
from warnings import warn

def main():
    BLOCK_TOGGLE = "---"
    # TODO bikeshed this
    # TODO directives: source, to source a file verbatim,
    # execute, to execute a script. Considerations for execute: shebang, arguments
    parser = argparse.ArgumentParser()
    parser.add_argument("file", nargs="+", help="a file to process")
    parser.add_argument("-f", "--force")
    args = parser.parse_args()
    print(args)

    for filename in args.file:
        # Get an absolute path, and an output path with one extension removed, if
        # present, and the extension ".gmi" added
        absolute = pathlib.Path(filename).expanduser().absolute()
        output = absolute.parent / (absolute.stem + ".gmi")
        print(f"absolute: {absolute}\noutput: {output}")

        if absolute == output and not args.force:
            warn(f"Output file {output} is the same as input file")
            continue

        # If we're not forcing, use the exclusive-creation mode "x" - this fails if
        # the file to open already exists
        outmode = "w" if args.force else "x"

        with open(absolute, "r") as infile:
            for line in infile.readlines():
                pass

        # Finally, we want to process the file, outputting to output file.
        #
        # Considerations: (obsolete?) {{{
        # What if we want to output to stdout? We would want output to be easily configurable, but with a good default.
        # Something like yt-dlp's -o option?
        #
        # Which of input and output should just be '.gmi', and what should the other be?
        # 2023-02-25 maybe .grw for gemini-raw, output to .gmi? If .gmi already present, then skip and warn unless forced.
        # }}}
        #
        # Considerations (not obsolete)
        # Have a 'path' directive, for setting path relative to gemlog root; you should be able to read this, too, so you can
        # have branches based on the path.
        # Maybe not even a path directive, just a directive to declare a variable, one to check a variable, and conditionals.
        # Or is directive even the right word? Do we want an actual programming language?
        # (We could probably fork/exec Lua into this, but it would be easier to just use python, since it's already python.)

if __name__ == "__main__":
    main()
